#ifndef _IMQMGR_HPP_
#define _IMQMGR_HPP_

//  Library:       MQSeries
//  Component:     IMQI (MQSeries C++ MQI)
//  Part:          IMQMGR.HPP
//
//  Description:   "ImqQueueManager" class declaration
//
//  Statement:     Licensed Materials - Property of IBM
//                 5621-390, 5765-623
//                 (C) Copyright IBM Corp. 1994, 1996
//
//                 U.S. Government Users Restricted Rights -
//                 use, duplication or disclosure restricted by
//                 GSA ADP Schedule Contract with IBM Corp.

#include <imqobj.hpp> // ImqObject

class ImqQueueManager : public ImqObject {
  ImqQueueManager * opmgrNext ;
  ImqQueueManager * opmgrPrevious ;
  ImqObject * opobjectFirst ;
  ImqBoolean obConnected ;
  ImqBoolean obPadding1[ 3 ];
  // New methods:
  static void lock ( );
  static void unlock ( );
protected :
  friend class ImqObject ;
  MQHCONN ohconn ;
  // New methods:
  void setFirstManagedObject ( const ImqObject * pobject = 0 )
    { opobjectFirst = (ImqObject *)pobject ; }
public :
  // Overloaded "ImqObject" methods:
  virtual ImqBoolean description ( ImqString & );
  virtual ImqBoolean name ( ImqString & );
  // Directed "ImqObject" methods:
  ImqString name ( ) { return ImqObject::name( ); }
  // New methods:
  ImqQueueManager ( );
  ImqQueueManager ( const char * );
  ImqQueueManager ( const ImqQueueManager & );
  virtual ~ ImqQueueManager ( );
  void operator = ( const ImqQueueManager & );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean authorityEvent ( long & );
  long authorityEvent ( );
#endif
  ImqBoolean backout ( );
  ImqBoolean begin ( );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  long characterSet ( );
  ImqBoolean characterSet ( long & );
  ImqBoolean commandInputQueueName ( ImqString & );
  ImqString commandInputQueueName ( );
  ImqBoolean commandLevel ( long & );
  long commandLevel ( );
#endif
  ImqBoolean commit ( );
  ImqBoolean connect ( );
  ImqBoolean connectionStatus ( ) const { return obConnected ; }
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqString deadLetterQueueName ( );
  ImqBoolean deadLetterQueueName ( ImqString & );
  ImqBoolean defaultTransmissionQueueName ( ImqString & );
  ImqString defaultTransmissionQueueName ( );
#endif
  ImqBoolean disconnect ( );
  ImqObject * firstManagedObject ( ) const { return opobjectFirst ; }
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean inhibitEvent ( long & );
  long inhibitEvent ( );
  ImqBoolean localEvent ( long & );
  long localEvent ( );
  ImqBoolean maximumHandles ( long & );
  long maximumHandles ( );
  ImqBoolean maximumMessageLength ( long & );
  long maximumMessageLength ( );
  long maximumPriority ( );
  ImqBoolean maximumPriority ( long & );
  ImqBoolean maximumUncommittedMessages ( long & );
  long maximumUncommittedMessages ( );
  ImqBoolean performanceEvent ( long & );
  long performanceEvent ( );
  ImqBoolean platform ( long & );
  long platform ( );
  ImqBoolean remoteEvent ( long & );
  long remoteEvent ( );
  ImqBoolean startStopEvent ( long & );
  long startStopEvent ( );
#endif
  long syncPointAvailability ( );
  ImqBoolean syncPointAvailability ( long & );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean triggerInterval ( long & );
  long triggerInterval ( );
#endif
} ;

#endif
