#ifndef _IMQMSG_HPP_
#define _IMQMSG_HPP_

//  Library:       MQSeries
//  Component:     IMQI (MQSeries C++ MQI)
//  Part:          IMQMSG.HPP
//
//  Description:   "ImqMessage" class declaration
//
//  Statement:     Licensed Materials - Property of IBM
//                 5621-390, 5765-623
//                 (C) Copyright IBM Corp. 1994, 1996
//
//                 U.S. Government Users Restricted Rights -
//                 use, duplication or disclosure restricted by
//                 GSA ADP Schedule Contract with IBM Corp.

extern "C" {
#include <cmqc.h>
}

#include <imqbin.hpp> // ImqBinary
#include <imqcac.hpp> // ImqCache
#include <imqstr.hpp> // ImqString

#if defined( _IMQ_VER ) && ( _IMQ_VER < 200 )
#define MQFMT_STRING "MQSTR   "
#endif

#define ImqMessage                        ImqMsg

class ImqItm ;
class ImqQue ;
class ImqMessage : public ImqCache {
protected :
  MQMD omqmd ;
  friend class ImqQue ;
public :
  // New methods:
  ImqMessage ( );
  ImqMessage ( const ImqMessage & );
  virtual ~ ImqMessage ( );
  void operator = ( const ImqMessage & );
  ImqBinary accountingToken ( ) const ;
  ImqString applicationIdData ( ) const ;
  ImqString applicationOriginData ( ) const ;
  long backoutCount ( ) const { return omqmd.BackoutCount ; }
  long characterSet ( ) const { return omqmd.CodedCharSetId ; }
  ImqBinary correlationId ( ) const ;
  long encoding ( ) const { return omqmd.Encoding ; }
  long expiry ( ) const { return omqmd.Expiry ; }
  long feedback ( ) const { return omqmd.Feedback ; }
  ImqString format ( ) const ;
  ImqBoolean formatIs ( const char * ) const ;
  ImqBinary messageId ( ) const ;
  long messageType ( ) const { return omqmd.MsgType ; }
  long persistence ( ) const { return omqmd.Persistence ; }
  long priority ( ) const { return omqmd.Priority ; }
  ImqString putApplicationName ( ) const ;
  long putApplicationType ( ) const { return omqmd.PutApplType ; }
  ImqString putDate ( ) const ;
  ImqString putTime ( ) const ;
  ImqBoolean readItem ( ImqItm & );
  ImqString replyToQueueManagerName ( ) const ;
  ImqString replyToQueueName ( ) const ;
  long report ( ) const { return omqmd.Report ; }
  ImqBoolean setAccountingToken ( const ImqBinary & );
  void setAccountingToken ( const unsigned char * = 0 );
  void setApplicationIdData ( const char * = 0 );
  void setApplicationOriginData ( const char * = 0 );
  void setCharacterSet ( const long lSet = MQCCSI_Q_MGR )
    { omqmd.CodedCharSetId = lSet ; }
  ImqBoolean setCorrelationId ( const ImqBinary & );
  void setCorrelationId ( const unsigned char * = 0 );
  void setEncoding ( const long lEncoding = MQENC_NATIVE )
    { omqmd.Encoding = lEncoding ; }
  void setExpiry ( const long lExpiry ) { omqmd.Expiry = lExpiry ; }
  void setFeedback ( const long lFeedback ) { omqmd.Feedback = lFeedback ; }
  void setFormat ( const char * = 0 );
  ImqBoolean setMessageId ( const ImqBinary & );
  void setMessageId ( const unsigned char * = 0 );
  void setMessageType ( const long lType ) { omqmd.MsgType = lType ; }
  void setPersistence ( const long lPersistence )
    { omqmd.Persistence = lPersistence ; }
  void setPriority ( const long lPriority ) { omqmd.Priority = lPriority ; }
  void setPutApplicationName ( const char * = 0 );
  void setPutApplicationType ( const long lType = MQAT_NO_CONTEXT )
    { omqmd.PutApplType = lType ; }
  void setPutDate ( const char * = 0 );
  void setPutTime ( const char * = 0 );
  void setReplyToQueueManagerName ( const char * = 0 );
  void setReplyToQueueName ( const char * = 0 );
  void setReport ( const long lReport ) { omqmd.Report = lReport ; }
  void setUserId ( const char * = 0 );
  ImqString userId ( ) const ;
  ImqBoolean writeItem ( ImqItm & );
} ;

#endif
