#ifndef _IMQOBJ_HPP_
#define _IMQOBJ_HPP_

//  Library:       MQSeries
//  Component:     IMQI (MQSeries C++ MQI)
//  Part:          IMQOBJ.HPP
//
//  Description:   "ImqObject" class declaration
//
//  Statement:     Licensed Materials - Property of IBM
//                 5621-390, 5765-623
//                 (C) Copyright IBM Corp. 1994, 1996
//
//                 U.S. Government Users Restricted Rights -
//                 use, duplication or disclosure restricted by
//                 GSA ADP Schedule Contract with IBM Corp.

extern "C" {
#include <cmqc.h>
}

#include <imqerr.hpp> // ImqError
#include <imqstr.hpp> // ImqString

#define ImqObject       ImqObj
#define ImqQueueManager ImqMgr

class ImqQueueManager ;
class ImqPmo ;
class ImqObject : public ImqError {
  long olOpenOptions ;
  long olCloseOptions ;
  ImqQueueManager * opmanager ;
  ImqObject * opobjectNext ;
  ImqObject * opobjectPrevious ;
protected :
  friend class ImqPmo ;
  MQHOBJ ohobj ;
  MQOD omqod ;
  unsigned int obOpen : 1 ;
  unsigned int obContextSaved : 1 ;
  unsigned int obBrowsing : 1 ;
  unsigned int obCursorLost : 1 ;
  unsigned int obPadding1 : 4 ;
  char ocPadding1[ 3 ];
  // New methods:
  MQHCONN connectionHandle( ) const ;
  virtual ImqBoolean closeTemporarily ( );
  ImqBoolean inquire ( const long, long & );
  ImqBoolean inquire ( const long, char * &, const long );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean set ( const long, const long );
  ImqBoolean set ( const long, const char *, const long );
#endif
  void setNextManagedObject ( const ImqObject * pobject = 0 )
    { opobjectNext = (ImqObject *)pobject ; }
  void setPreviousManagedObject ( const ImqObject * pobject = 0 )
    { opobjectPrevious = (ImqObject *)pobject ; }
public :
  // New methods:
  ImqObject ( );
  ImqObject ( const ImqObject & );
  virtual ~ ImqObject ( );
  void operator = ( const ImqObject & );
  ImqString alternateUserId ( ) const ;
  ImqBoolean close ( );
  long closeOptions ( ) const { return olCloseOptions ; }
  ImqQueueManager * connectionReference ( ) const { return opmanager ; }
  virtual ImqBoolean description ( ImqString & ) = 0 ;
  ImqString description ( ) ;
  virtual ImqBoolean name ( ImqString & );
  ImqString name ( );
  ImqObject * nextManagedObject ( ) const { return opobjectNext ; }
  ImqBoolean open ( );
  ImqBoolean openFor ( const long = 0 );
  long openOptions ( ) const { return olOpenOptions ; }
  ImqBoolean openStatus ( ) const { return (ImqBoolean)obOpen ; }
  ImqObject * previousManagedObject ( ) const { return opobjectPrevious ; }
  ImqBoolean setAlternateUserId ( const char * );
  void setCloseOptions ( const long lCloseOptions )
    { olCloseOptions = lCloseOptions ; }
  void setConnectionReference ( ImqQueueManager * = 0 );
  void setConnectionReference ( ImqQueueManager & mgr )
    { setConnectionReference( & mgr ); }
  ImqBoolean setName ( const char * = 0 );
  ImqBoolean setOpenOptions ( const long );
} ;

#endif
