#ifndef _IMQQUE_HPP_
#define _IMQQUE_HPP_

//  Library:       MQSeries
//  Component:     IMQI (MQSeries C++ MQI)
//  Part:          IMQQUE.HPP
//
//  Description:   "ImqQueue" class declaration
//
//  Statement:     Licensed Materials - Property of IBM
//                 5621-390, 5765-623
//                 (C) Copyright IBM Corp. 1994, 1996
//
//                 U.S. Government Users Restricted Rights -
//                 use, duplication or disclosure restricted by
//                 GSA ADP Schedule Contract with IBM Corp.

#include <imqgmo.hpp> // ImqGetMessageOptions
#include <imqpmo.hpp> // ImqPutMessageOptions
#include <imqobj.hpp> // ImqObject

#if defined( _IMQ_VER ) && ( _IMQ_VER < 200 )
#define MQRC_CONTEXT_HANDLE_ERROR      2097L
#define MQRC_CONTEXT_NOT_AVAILABLE     2098L
#define MQRC_FORMAT_ERROR              2110L
#endif

#define MQRC_NO_OBJECT                 2297L

#define ImqQueue ImqQue

class ImqMsg ;
class ImqQueue : public ImqObject {
  ImqQueue * opqueueNext ;
  ImqQueue * opqueuePrevious ;
  // New methods:
  void add ( );
  ImqBoolean genericGet ( const MQHCONN, ImqMsg &, const long, void *, long &,
                          MQGMO * );
  ImqBoolean genericPut ( const MQHCONN, ImqMsg &, const long, void *,
                          MQPMO * );
  void init ( );
  static void lock ( );
  static void unlock ( );
public :
  // Overloaded "ImqObject" methods:
  virtual ImqBoolean closeTemporarily ( );
  virtual ImqBoolean description ( ImqString & );
  virtual ImqBoolean name ( ImqString & );
  // Directed "ImqObject" methods:
  ImqString name ( ) { return ImqObject::name( ); }
  // New methods:
  ImqQueue ( );
  ImqQueue ( const char * );
  ImqQueue ( const ImqQueue & );
  virtual ~ ImqQueue ( );
  void operator = ( const ImqQueue & );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean backoutRequeueName ( ImqString & );
  ImqString backoutRequeueName ( ); 
  ImqBoolean backoutThreshold ( long & );
  long backoutThreshold ( ); 
#endif
  ImqBoolean baseQueueName ( ImqString & );
  ImqString baseQueueName ( );
  ImqBoolean creationDate ( ImqString & );
  ImqString creationDate ( );
  ImqBoolean creationTime ( ImqString & );
  ImqString creationTime ( ); 
  ImqBoolean currentDepth ( long & );
  long currentDepth ( );     
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean defaultInputOpenOption ( long & );
  long  defaultInputOpenOption ( );
#endif
  ImqBoolean defaultPersistence ( long & );
  long defaultPersistence ( );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean defaultPriority ( long & );
  long defaultPriority ( );
#endif
  ImqBoolean definitionType ( long & );
  long definitionType ( );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean depthHighEvent ( long & );
  long depthHighEvent ( );
  ImqBoolean depthHighLimit ( long & );
  long depthHighLimit ( );
  ImqBoolean depthLowEvent ( long & );
  long depthLowEvent ( );
  ImqBoolean depthLowLimit ( long & );
  long depthLowLimit ( );
  ImqBoolean depthMaximumEvent ( long & );
  long depthMaximumEvent ( );
#endif
  ImqString dynamicQueueName ( ) const ;
  ImqBoolean get ( ImqMsg & );
  ImqBoolean get ( ImqMsg &, ImqGetMessageOptions & );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean hardenGetBackout ( long & );
  long hardenGetBackout ( );
#endif
  ImqBoolean inhibitGet ( long & );
  long inhibitGet ( );
  ImqBoolean inhibitPut ( long & );
  long inhibitPut ( );
  ImqBoolean initiationQueueName ( ImqString & );
  ImqString initiationQueueName ( );
  ImqBoolean maximumDepth ( long & );
  long maximumDepth ( );
  ImqBoolean maximumMessageLength ( long & );
  long maximumMessageLength ( );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean messageDeliverySequence ( long & );
  long messageDeliverySequence ( );
#endif
  ImqBoolean openInputCount ( long & );
  long openInputCount ( );
  ImqBoolean openOutputCount ( long & );
  long openOutputCount ( );
  ImqBoolean processName ( ImqString & );
  ImqString processName ( );
  ImqBoolean put ( ImqMsg & );
  ImqBoolean put ( ImqMsg &, ImqPutMessageOptions & );
  ImqString queueManagerName ( ) const ;
  ImqBoolean queueType ( long & );
  long queueType ( );
  ImqBoolean remoteQueueManagerName ( ImqString & );
  ImqString remoteQueueManagerName ( );
  ImqBoolean remoteQueueName ( ImqString & );
  ImqString remoteQueueName ( );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean retentionInterval ( long & );
  long retentionInterval ( );
  ImqBoolean scope ( long & );
  long scope ( );
  ImqBoolean serviceInterval ( long & );
  long serviceInterval ( );
  ImqBoolean serviceIntervalEvent ( long & );
  long serviceIntervalEvent ( );
#endif
  ImqBoolean setDynamicQueueName ( const char * );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean setInhibitGet ( const long );
  ImqBoolean setInhibitPut ( const long );
#endif
  ImqBoolean setQueueManagerName ( const char * );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean setTriggerControl ( const long );
  ImqBoolean setTriggerData ( const char * );
  ImqBoolean setTriggerDepth ( const long );
  ImqBoolean setTriggerMessagePriority ( const long );
  ImqBoolean setTriggerType ( const long );
#endif
  ImqBoolean shareability ( long & );
  long shareability ( );
  ImqBoolean transmissionQueueName ( ImqString & );
  ImqString transmissionQueueName ( );
  ImqBoolean triggerControl ( long & );
  long triggerControl ( );
#if defined( _IMQ_VER ) && ( _IMQ_VER >= 200 )
  ImqBoolean triggerData ( ImqString & );
  ImqString triggerData ( );
  ImqBoolean triggerDepth ( long & );
  long triggerDepth ( );
  ImqBoolean triggerMessagePriority ( long & );
  long triggerMessagePriority ( ); 
#endif
  ImqBoolean triggerType ( long & );
  long triggerType ( );
  ImqBoolean usage ( long & );
  long usage ( );
} ;

#endif
