#ifndef _IMQSTR_HPP_
#define _IMQSTR_HPP_

//  Library:       MQSeries
//  Component:     IMQB (MQSeries C++ Support)
//  Part:          IMQSTR.HPP
//
//  Description:   "ImqString" class declaration
//
//  Statement:     Licensed Materials - Property of IBM
//                 5621-390, 5765-623
//                 (C) Copyright IBM Corp. 1994, 1996
//
//                 U.S. Government Users Restricted Rights -
//                 use, duplication or disclosure restricted by
//                 GSA ADP Schedule Contract with IBM Corp.

#include <imqitm.hpp> // ImqItem

#define ImqString ImqStr

class ImqString : public ImqItem {
  const ImqString concatenate ( const ImqString &, const ImqString & ) const ;
protected :
  char * opszString ;
  long olSize ;
  void assign ( const ImqString & );
public :
  // Overloaded "ImqItem" methods:
  virtual ImqBoolean copyOut ( ImqMsg & );
  virtual ImqBoolean pasteIn ( ImqMsg & );
  // New methods:
  ImqString ( );
  ImqString ( const ImqString & );
  ImqString ( const char );
  ImqString ( const char * );
  ImqString ( const void *, const long );
  virtual ~ ImqString ( );
  void operator = ( const ImqString & );
  ImqString operator + ( const ImqString & ) const ;
  ImqString operator + ( const char ) const ;
  ImqString operator + ( const char * ) const ;
  ImqString operator + ( const double ) const ;
  ImqString operator + ( const long ) const ;
  friend ImqString operator + ( const char * pszThis,
                                const ImqString & strThat )
    { return (ImqString)pszThis + strThat ; }
  void operator += ( const ImqString & );
  void operator += ( const char );
  void operator += ( const char * );
  void operator += ( const double );
  void operator += ( const long );
  ImqString operator ( ) ( const long, const long = 1 ) const ;
  operator char * ( ) const { return opszString ; }
  char & operator [ ] ( const long lIndex ) const
    { return * ( opszString + lIndex ); }
  ImqBoolean operator < ( const ImqString & str ) const
    { return this -> compare( str ) < 0 ; }
  ImqBoolean operator > ( const ImqString & str ) const
    { return this -> compare( str ) > 0 ; }
  ImqBoolean operator <= ( const ImqString & str ) const
    { return this -> compare( str ) <= 0 ; }
  ImqBoolean operator >= ( const ImqString & str ) const
    { return this -> compare( str ) >= 0 ; }
  ImqBoolean operator == ( const ImqString & str ) const
    { return this -> compare( str ) == 0 ; }
  ImqBoolean operator != ( const ImqString & str ) const
    { return this -> compare( str ) != 0 ; }
  short compare ( const ImqString & ) const ;
  static ImqBoolean copy ( char *, const long, const char *, const char = 0 );
  ImqBoolean copyOut ( char *, const long, const char = 0 ) const ;
  long copyOut ( long & ) const ;
  long copyOut ( ImqString &, const char = ' ' ) const ;
  long cutOut ( long & );
  long cutOut ( ImqString &, const char = ' ' );
  ImqBoolean find ( const ImqString & ) const ;
  ImqBoolean find ( const ImqString &, long & ) const ;
  long length ( ) const ;
  ImqBoolean pasteIn ( const double, const char * = "%f" );
  ImqBoolean pasteIn ( const long );
  void pasteIn ( const void *, const long );
  ImqBoolean set ( const char *, const long );
  long storage ( ) const { return olSize ; }
  long setStorage ( const long );
  long stripLeading ( const char = ' ' );
  long stripTrailing ( const char = ' ' );
  ImqString upperCase ( ) const ;
} ;

#endif
